# django-redis-data-manager

A simple django application provide simple redis cache data manager functional.


## Install

```
pip install django-redis-data-manager
```

## Install Server Command

- manage-django-redis-data-manager

**Command Help**

```
C:\Workspace\redis-dataman>manage-django-redis-data-manager

Type 'manage-django-redis-data-manager help <subcommand>' for help on a specific subcommand.

Available subcommands:

[auth]
    changepassword
    createsuperuser

[contenttypes]
    remove_stale_contenttypes

[django]
    check
    compilemessages
    createcachetable
    dbshell
    diffsettings
    dumpdata
    flush
    inspectdb
    loaddata
    makemessages
    makemigrations
    migrate
    sendtestemail
    shell
    showmigrations
    sqlflush
    sqlmigrate
    sqlsequencereset
    squashmigrations
    startapp
    startproject
    test
    testserver

[django_server_controller]
    wsgi-server

[sessions]
    clearsessions

[staticfiles]
    collectstatic
    findstatic
    runserver
```

## Releases


### v0.1.1 2020/09/25

- Add depends package in requirements.txt.

### v0.1.0 2020/09/23

- First release.